Python API Reference
====================

This section documents the Python interface of Fracnetics.

----

Utilities
---------

Helper functions used by the core classes are defined in the `utilsModel` module.

.. automodule:: fracnetics.utilsModel
   :members:
   :undoc-members:
   :show-inheritance:

